# Generated by Django 5.0.1 on 2024-05-22 07:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_paddle_billing', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='subscription',
            name='status',
            field=models.CharField(choices=[('active', 'Active'), ('canceled', 'Canceled'), ('past_due', 'Past Due'), ('paused', 'Paused'), ('trialing', 'Trialing')], max_length=10),
        ),
    ]
